@@ -2,7 +2,7 @@
 # HTML/Agent.pm - provides generic agent HTML output
 # Copyright (C) 2001-2003 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: Agent.pm,v 1.80 2003/02/03 23:40:41 martin Exp $
+# $Id: Agent.pm,v 1.80.2.3 2003/03/09 18:16:07 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,7 +14,7 @@ package Kernel::Output::HTML::Agent;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.80 $';
+$VERSION = '$Revision: 1.80.2.3 $';
 $VERSION =~ s/^.*:\s(\d+\.\d+)\s.*$/$1/;
 
 # --
@@ -244,6 +244,12 @@ sub TicketZoom {
     # create short html customer id
     # --
     $Param{CustomerIDHTML} = $Param{CustomerID} || '';
+    if ($Param{Lock} =~ /unlock/) {
+        $Param{Locked} = 2;
+    }
+    else {
+        $Param{Locked} = 1;
+    }
     # --
     # do some html quoting
     # --
@@ -428,7 +434,7 @@ sub TicketZoom {
     # --
     if ($Param{"ShowHTMLeMail"}) {
         # generate output
-        my $Output = "Content-Disposition: attachment; filename=";
+        my $Output = "Content-Disposition: inline; filename=";
         $Output .= $Self->{ConfigObject}->Get('TicketHook')."-$Param{TicketNumber}-";
         $Output .= "$Param{TicketID}-$Article{ArticleID}\n";
         $Output .= "Content-Type: $Article{MimeType}; charset=$Article{ContentCharset}\n";
@@ -1298,6 +1304,13 @@ sub AgentPreferencesForm {
                      $Self->Ascii2Html(Text => $Self->{$PrefKey}) .'">';
             }
           } 
+          elsif ($PrefKey eq 'UserLanguage') {
+              $PrefItem{'Option'} = $Self->OptionStrgHashRef(
+                  Data => $Self->{ConfigObject}->Get('DefaultUsedLanguages'),
+                  Name => "GenericTopic",
+                  SelectedID => $Self->{UserLanguage} || $Self->{ConfigObject}->Get('DefaultLanguage'),
+              );
+          }
           elsif ($Type eq 'CustomQueue') {
             my @CustomQueueIDs = $Self->{QueueObject}->GetAllCustomQueues(UserID => $Self->{UserID});
             # prepar custom selection
@@ -1538,11 +1551,10 @@ sub AgentSpelling {
     # --
     # dict language selection
     # --
-    my %Languages = ( 'English' => 'English', 'German' => 'German' );
     $Param{SpellLanguageString}  .= $Self->OptionStrgHashRef(
-        Data => \%Languages,
+        Data => $Self->{ConfigObject}->Get('PreferencesGroups')->{SpellDict}->{Data},
         Name => "SpellLanguage",
-        Selected => $Param{SpellLanguage}, 
+        SelectedID => $Param{SpellLanguage},
     );
     # --
     # create & return output
@@ -1552,4 +1564,3 @@ sub AgentSpelling {
 # --  
 
 1;
- 
