@@ -2,7 +2,7 @@
 # Kernel/System/CustomerUser/LDAP.pm - some customer user functions in LDAP
 # Copyright (C) 2002 Wiktor Wodecki <wiktor.wodecki@net-m.de>
 # --
-# $Id: LDAP.pm,v 1.2 2003/02/03 19:33:20 martin Exp $
+# $Id: LDAP.pm,v 1.2.2.2 2003/02/11 12:40:48 wiktor Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -15,7 +15,7 @@ use strict;
 use Net::LDAP;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.2 $';
+$VERSION = '$Revision: 1.2.2.2 $';
 $VERSION =~ s/^.*:\s(\d+\.\d+)\s.*$/$1/;
 
 # --
@@ -85,7 +85,7 @@ sub CustomerSearch {
     my %Users = ();
     foreach my $entry ($Result->all_entries) {
         my $CustomerString = '';
-        foreach (@{$Self->{ConfigObject}->Get('CustomerUser')->{CustomerUserListFileds}}) {
+        foreach (@{$Self->{ConfigObject}->Get('CustomerUser')->{CustomerUserListFields}}) {
             $CustomerString .= $entry->get_value($_).' ';
         }
         $CustomerString =~ s/^(.*\s)(.+?\@.+?\..+?)(\s|)$/"$1" <$2>/;
@@ -107,7 +107,7 @@ sub CustomerList {
         scope => $Self->{SScope},
         filter => "($Self->{CustomerKey}=*)",
     );
-    $Result->code && die $Result->error;
+    $Result->code || die $Result->error;
     my %Users = ();
     foreach my $entry ($Result->all_entries) {
         my $CustomerString = '';
@@ -276,7 +276,7 @@ sub Destroy {
     # --
     # take down session
     # --
-    $LDAP->unbind;
+    $Self->{LDAP}->unbind;
     return 1;
 }
 # --
